package vo

import "gitea.cdlsxd.cn/BaseSystem/plugin/proto"

// OperaSt 原操作状态；10表示原操作未被受理；00表示原操作成功；01表示原操作结果未明；其他表示原操作失败
type OperaSt string

const (
	OperaStSuccess          OperaSt = "00"
	OperaStNotAccepted      OperaSt = "10"
	OperaStResultIsNotClear OperaSt = "01"
)

var operaStMap = map[OperaSt]string{
	OperaStSuccess:          "原操作成功",
	OperaStNotAccepted:      "原操作未被受理",
	OperaStResultIsNotClear: "原操作结果未明",
}

var queryOrderStatusMap = map[OperaSt]proto.Status{
	OperaStSuccess:          proto.Status_SUCCESS,
	OperaStResultIsNotClear: proto.Status_ING,
	OperaStNotAccepted:      proto.Status_INVALID,
}

func (o OperaSt) GetText() string {
	msg, ok := operaStMap[o]
	if !ok {
		return "原操作失败"
	}
	return msg
}

func (o OperaSt) GetOrderStatus() proto.Status {
	if len(o) == 0 {
		return proto.Status_INVALID
	}
	if resultStatus, ok := queryOrderStatusMap[o]; ok {
		return resultStatus
	}
	return proto.Status_FAIL
}
