package internal

import (
	"context"
	"gitea.cdlsxd.cn/BaseSystem/plugin/proto"
	"plugins/weixin_cpn/internal/vo"
)

// 插件通信信息,若不对应则会报错panic
const (
	Tag         = "weixin_pay_cpn"
	Version     = 1
	CookieKey   = "weixin_pay_cpn"
	CookieValue = "weixin_pay_cpn"
)

type WeiXinCpnService struct{}

func (p *WeiXinCpnService) Order(ctx context.Context, request *proto.OrderRequest) (*proto.OrderResponse, error) {
	config, err := transConfig(request.Config)
	if err != nil {
		return nil, err
	}
	svc, err := getApiSrv(ctx, config)
	if err != nil {
		return nil, err
	}
	req, err := orderReq(request.GetOrder(), request.GetProduct())
	if err != nil {
		return nil, err
	}
	resp, result, err := svc.SendCoupon(ctx, req)
	if err != nil {
		return nil, err
	}
	if result.Response.StatusCode != vo.CodeSuccess.Value() {
		return nil, err
	}
	return orderResp(request.GetOrder(), *resp.CouponId), nil
}

func (p *WeiXinCpnService) Query(ctx context.Context, request *proto.QueryRequest) (*proto.QueryResponse, error) {
	config, err := transConfig(request.Config)
	svc, err := getApiSrv(ctx, config)
	if err != nil {
		return nil, err
	}
	req, err := queryReq(request.GetOrder())
	if err != nil {
		return nil, err
	}
	resp, result, err := svc.QueryCoupon(ctx, *req)
	if err != nil {
		return nil, err
	}
	if result.Response.StatusCode != vo.CodeSuccess.Value() {
		return nil, err
	}
	return queryResp(request, resp), nil
}

func (p *WeiXinCpnService) Notify(_ context.Context, request *proto.NotifyRequest) (*proto.NotifyResponse, error) {
	return notifyResp(), nil
}
